aboutsummaryrefslogtreecommitdiffstats
path: root/modules/home.legacy/pkgs/default.nix
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--modules/home.legacy/pkgs/default.nix104
1 files changed, 13 insertions, 91 deletions
diff --git a/modules/home.legacy/pkgs/default.nix b/modules/home.legacy/pkgs/default.nix
index 859aea36..840ffb19 100644
--- a/modules/home.legacy/pkgs/default.nix
+++ b/modules/home.legacy/pkgs/default.nix
@@ -1,58 +1,28 @@
+# nixos-config - My current NixOS configuration
+#
+# Copyright (C) 2025 Benedikt Peetz <benedikt.peetz@b-peetz.de>
+# SPDX-License-Identifier: GPL-3.0-or-later
+#
+# This file is part of my nixos-config.
+#
+# You should have received a copy of the License along with this program.
+# If not, see <https://www.gnu.org/licenses/gpl-3.0.txt>.
{
pkgs,
lib,
- config,
nixosConfig,
...
}:
# TODO: Remove this whole file, and move each package to a separate module. <2024-11-16>
with pkgs; let
- neorgFinal =
- neorg.override
- {
- defaultNeorgProjectDir = config.programs.nixvim.plugins.neorg.settings.load."core.dirman".config.workspaces.projects;
- allProjectsNewline = config.soispha.taskwarrior.projects.projects_newline;
- allProjectsComma = config.soispha.taskwarrior.projects.projects_comma;
- allProjectsPipe = config.soispha.taskwarrior.projects.projects_pipe;
- allWorkspaces = config.programs.nixvim.plugins.neorg.settings.load."core.dirman".config.workspaces;
- xdgConfigHome = config.xdg.configHome;
- xdgDataHome = config.xdg.dataHome;
- };
-
Gui = {
- Terminals = [
- alacritty # default terminal
- ];
-
- Social = [
- signal-desktop # to avoid encryption problems with signal-bridge
- ];
-
Misc = [
keepassxc # password manager
- anki-bin # spaced repetition
];
};
TuiCli = {
- EyeCandy = [
- hyfetch # Neofetch with LGBTQ pride flags.
- ];
-
- Social = [
- iamb # best tui matrix client (as of today)
- ];
-
- Pdfs = [
- con2pdf # Scanner implementation
- ];
-
Misc = [
- android-file-transfer # Android MTP client with minimalistic UI
- #xdg-ninja # A shell script which checks your $HOME for unwanted files and directories.
- xdg-utils # open urls and such things
- killall # kill a application by name
- snap-sync-forked # A btrfs based backup solution
bc # Smart calculator
aumo # Automatic mount
jq # Json parser
@@ -65,34 +35,16 @@ with pkgs; let
];
Firefox = [
# `neorg` handles the integration between Firefox profiles and task
# contexts
- neorgFinal
+ pkgs.tskm
];
};
WM = {
CLITools = [
- lswt # List Wayland toplevels.
wl-clipboard # Command-line copy/paste utilities.
];
-
- Media = [
- libnotify # a command to send a notification.
- ];
- };
-
- Media = {
- View = [
- imv # Image viewer
- zathura # PDF viewer
- ];
-
- YouTube = [
- yt # A command line YouTube client
- ];
-
- Listen = [];
};
Hardware = {
@@ -118,38 +70,17 @@ with pkgs; let
SystemUpdate = [
fupdate # Generic update tool.
- update-sys # System update tool (meant to slot into `fupdate`).
+ fupdate-sys # System update tool (meant to slot into `fupdate`).
+ fupdate-flake # Nix flake update tool (meant to slot into `fupdate`).
];
FileListers = [
tree # A directory listing program displaying a depth indented list of files
fd # Simple, fast and user-friendly alternative to find
ripgrep # A search tool that combines the usability of ag with the raw speed of grep
- fzf # used to quickly move around with its keybindings
file # Show information about a file
- ll # Wrapper around `lf` to automatically change the path
- lm # Wrapper around `ll` to automatically cd to the last accessed path
];
-
- Editors = [
- ed # A POSIX-compliant line-oriented text editor
- #sed # GNU stream editor
- vim # The original ex/vi text editor (this is `vim` and not `vi`, as `vi` is unfree)
- #neovim # Fork of Vim aiming to improve user experience, plugins, and GUIs
- ];
-
- Programming = {
- GeneralTools = [
- stamp # Add a license header to a file
- git # the fast distributed version control system
- git-edit-index # Allows you to edit the indexed version of a file
- git-cm # A wrapper that re-adds the last commit's subject
- glow # Command-line markdown renderer
- ];
- };
};
- # TODO: unmaintained, find sth else:
- # handlr # Powerful alternative to xdg-utils written in Rust
mapFun = x:
if builtins.isAttrs x
then
@@ -158,15 +89,6 @@ with pkgs; let
else builtins.attrValues x
else [x];
in {
- options.soispha.programs.neorg = {
- package = lib.mkOption {
- type = lib.types.package;
- default = neorgFinal;
- description = ''
- The neorg package to use.
- '';
- };
- };
config.home.packages =
[]
++ (with builtins;
@@ -65,34 +35,16 @@ with pkgs; let
];
Firefox = [
- # `neorg` handles the integration between Firefox profiles and task
+ # `tskm` handles the integration between Firefox profiles and task
# contexts